/*
 xGL:Node.h
 Created by mantis on 4/07/05.
 Copyright 2005 xonko interactive. All rights reserved.
 */

#import <Cocoa/Cocoa.h>
#import "vectorLib.h"


@interface XGLNode : NSObject {

	vector position;
	vector rotation;
	vector scale;
	vector bufferVector;
	
	bool isInWorld;
	
	bool isAnimated;
	vector linearVelocity;
	vector angularVelocity;
	
	//vector gravity;
	//float drag;
	
	NSMutableArray *children;
	
	XGLNode *parent;
	
	NSString *name;

}

//+(Class)class;

-(id)init;

-(NSString *)name;
-(void)setName:(NSString *)aName;

-(void)rotate:(float)x :(float)y :(float)z;
-(void)translate:(float)x :(float)y :(float)z;
-(void)inflate:(float)x :(float)y :(float)z;

-(void)rotateByVector:(vector)aVector;
-(void)translateByVector:(vector)aVector;
-(void)inflateByVector:(vector)aVector;

-(vector)position;
-(vector)rotation;
-(vector)scale;

-(void)setPosition:(vector)aVector;
-(void)setRotation:(vector)aVector;
-(void)setScale:(vector)aVector;

-(bool)isInWorld;
-(void)addToWorld;
-(void)removeFromWorld;
-(void)setIsInWorld:(bool)newIsInWorld;

-(bool)isAnimated;
-(void)setAnimated:(bool)yesNo;

-(vector)linearVelocity;
-(vector)angularVelocity;

-(void)setLinearVelocity:(vector)aVector;
-(void)setAngularVelocity:(vector)aVector;

-(void)applyImpulse:(float)x :(float)y :(float)z;
-(void)applyImpulseByVector:(vector)aVector;

-(void)applyAngularImpulse:(float)x :(float)y :(float)z;
-(void)applyAngularImpulseByVector:(vector)aVector;

-(id)children;
-(int)numberOfChildren;
-(void)addChild:(id)childObject;
-(void)removeChild:(id)childObject;
-(void)addChildSilently:(id)childObject;

-(id)parent;
-(void)setParent:(id)newParent;
-(void)setParentSilently:(id)newParent;


-(void)animate;
-(void)render;
-(void)drawOpenGL;
-(void)eraseNode;

-(float)pX;
-(float)pY;
-(float)pZ;

-(void)setPX:(float)newPos;
-(void)setPY:(float)newPos;
-(void)setPZ:(float)newPos;

-(float)rX;
-(float)rY;
-(float)rZ;

-(void)setRX:(float)newPos;
-(void)setRY:(float)newPos;
-(void)setRZ:(float)newPos;

-(float)sX;
-(float)sY;
-(float)sZ;

-(void)setSX:(float)newPos;
-(void)setSY:(float)newPos;
-(void)setSZ:(float)newPos;


	//linearVelocity KVC
-(float)lvX;
-(float)lvY;
-(float)lvZ;

-(void)setLvX:(float)newPos;
-(void)setLvY:(float)newPos;
-(void)setLvZ:(float)newPos;

//angularVelocity KVC
-(float)avX;
-(float)avY;
-(float)avZ;

-(void)setAvX:(float)newPos;
-(void)setAvY:(float)newPos;
-(void)setAvZ:(float)newPos;

//-(float *)identity;

@end
